@@ -19,6 +19,7 @@
 #include <inttypes.h>
 #include <stddef.h>
 #include "mdbtools.h"
+#include "mdbprivate.h"
 
 MdbFormatConstants MdbJet4Constants = {
 	.pg_size = 4096,
@@ -31,6 +32,8 @@ MdbFormatConstants MdbJet4Constants = {
     .tab_first_dpg_offset = 56,
     .tab_cols_start_offset = 63,
     .tab_ridx_entry_size = 12,
+    .col_scale_offset = 11,
+    .col_prec_offset = 12,
     .col_flags_offset = 15,
     .col_size_offset = 23,
     .col_num_offset = 5,
@@ -51,6 +54,8 @@ MdbFormatConstants MdbJet3Constants = {
     .tab_first_dpg_offset = 36,
     .tab_cols_start_offset = 43,
     .tab_ridx_entry_size = 8,
+    .col_scale_offset = 9,
+    .col_prec_offset = 10,
     .col_flags_offset = 13,
     .col_size_offset = 16,
     .col_num_offset = 1,
@@ -218,6 +223,7 @@ static MdbHandle *mdb_handle_from_stream(FILE *stream, MdbFileFlags flags) {
 	case MDB_VER_ACCDB_2010:
 	case MDB_VER_ACCDB_2013:
 	case MDB_VER_ACCDB_2016:
+	case MDB_VER_ACCDB_2019:
 		mdb->fmt = &MdbJet4Constants;
 		break;
 	default:
@@ -355,14 +361,14 @@ MdbHandle *mdb_clone_handle(MdbHandle *mdb)
 	MdbCatalogEntry *entry, *data;
 	unsigned int i;
 
-	newmdb = (MdbHandle *) g_memdup(mdb, sizeof(MdbHandle));
+	newmdb = (MdbHandle *) g_memdup2(mdb, sizeof(MdbHandle));
 
 	memset(&newmdb->catalog, 0, sizeof(MdbHandle) - offsetof(MdbHandle, catalog));
 
 	newmdb->catalog = g_ptr_array_new();
 	for (i=0;i<mdb->num_catalog;i++) {
 		entry = g_ptr_array_index(mdb->catalog,i);
-		data = g_memdup(entry,sizeof(MdbCatalogEntry));
+		data = g_memdup2(entry,sizeof(MdbCatalogEntry));
 		data->mdb = newmdb;
 		data->props = NULL;
 		g_ptr_array_add(newmdb->catalog, data);
